@@ -1,11 +1,12 @@
-use std::borrow::Borrow;
 use std::hash::{Hash, Hasher};
 use std::sync::atomic::{AtomicU32, Ordering};
-use std::sync::{Mutex, MutexGuard};
+use std::sync::{RwLock, RwLockReadGuard, RwLockWriteGuard};
 use std::time::{SystemTime, UNIX_EPOCH};
 
 use ahash::RandomState;
+use hashbrown::hash_map::RawEntryMut;
 use once_cell::sync::Lazy;
+use polars_utils::HashSingle;
 use smartstring::{LazyCompact, SmartString};
 
 use crate::frame::groupby::hashing::HASHMAP_INIT_SIZE;
@@ -77,9 +78,77 @@ pub fn using_string_cache() -> bool {
     USE_STRING_CACHE.load(Ordering::Acquire) > 0
 }
 
+// This is the hash and the Index offset in the linear buffer
+#[derive(Copy, Clone)]
+struct Key {
+    pub(super) hash: u64,
+    pub(super) idx: u32,
+}
+
+impl Key {
+    #[inline]
+    pub(super) fn new(hash: u64, idx: u32) -> Self {
+        Self { hash, idx }
+    }
+}
+
+impl Hash for Key {
+    #[inline]
+    fn hash<H: Hasher>(&self, state: &mut H) {
+        state.write_u64(self.hash)
+    }
+}
+
 pub(crate) struct SCacheInner {
-    pub(crate) map: PlHashMap<StrHashGlobal, u32>,
+    map: PlHashMap<Key, ()>,
     pub(crate) uuid: u128,
+    payloads: Vec<StrHashGlobal>,
+}
+
+impl SCacheInner {
+    #[inline]
+    pub(crate) unsafe fn get_unchecked(&self, cat: u32) -> &str {
+        self.payloads.get_unchecked(cat as usize).as_str()
+    }
+
+    pub(crate) fn len(&self) -> usize {
+        self.map.len()
+    }
+
+    #[inline]
+    pub(crate) fn insert_from_hash(&mut self, h: u64, s: &str) -> u32 {
+        let mut global_idx = self.payloads.len() as u32;
+        // Note that we don't create the StrHashGlobal to search the key in the hashmap
+        // as StrHashGlobal may allocate a string
+        let entry = self.map.raw_entry_mut().from_hash(h, |key| {
+            (key.hash == h) && {
+                let pos = key.idx as usize;
+                let value = unsafe { self.payloads.get_unchecked(pos) };
+                s == value.as_str()
+            }
+        });
+
+        match entry {
+            RawEntryMut::Occupied(entry) => {
+                global_idx = entry.key().idx;
+            }
+            RawEntryMut::Vacant(entry) => {
+                let idx = self.payloads.len() as u32;
+                let key = Key::new(h, idx);
+                entry.insert_hashed_nocheck(h, key, ());
+
+                // only just now we allocate the string
+                self.payloads.push(s.into());
+            }
+        }
+        global_idx
+    }
+
+    #[inline]
+    pub(crate) fn insert(&mut self, s: &str) -> u32 {
+        let h = self.map.hasher().hash_single(s);
+        self.insert_from_hash(h, s)
+    }
 }
 
 impl Default for SCacheInner {
@@ -93,6 +162,7 @@ impl Default for SCacheInner {
                 .duration_since(UNIX_EPOCH)
                 .unwrap()
                 .as_nanos(),
+            payloads: Vec::with_capacity(HASHMAP_INIT_SIZE),
         }
     }
 }
@@ -101,7 +171,8 @@ impl Default for SCacheInner {
 /// In *eager* you need to specifically toggle global string cache to have a global effect.
 /// In *lazy* it is toggled on at the start of a computation run and turned of (deleted) when a
 /// result is produced.
-pub(crate) struct StringCache(pub(crate) Mutex<SCacheInner>);
+#[derive(Default)]
+pub(crate) struct StringCache(pub(crate) RwLock<SCacheInner>);
 
 impl StringCache {
     /// The global `StringCache` will always use a predictable seed. This allows local builders to mimic
@@ -111,8 +182,12 @@ impl StringCache {
     }
 
     /// Lock the string cache
-    pub(crate) fn lock_map(&self) -> MutexGuard<SCacheInner> {
-        self.0.lock().unwrap()
+    pub(crate) fn lock_map(&self) -> RwLockWriteGuard<SCacheInner> {
+        self.0.write().unwrap()
+    }
+
+    pub(crate) fn read_map(&self) -> RwLockReadGuard<SCacheInner> {
+        self.0.read().unwrap()
     }
 
     pub(crate) fn clear(&self) {
@@ -121,42 +196,6 @@ impl StringCache {
     }
 }
 
-impl Default for StringCache {
-    fn default() -> Self {
-        StringCache(Mutex::new(Default::default()))
-    }
-}
-
 pub(crate) static STRING_CACHE: Lazy<StringCache> = Lazy::new(Default::default);
 
-#[derive(Eq, Clone)]
-pub struct StrHashGlobal {
-    pub(crate) str: SmartString<LazyCompact>,
-    pub(crate) hash: u64,
-}
-
-impl Hash for StrHashGlobal {
-    fn hash<H: Hasher>(&self, state: &mut H) {
-        state.write_u64(self.hash)
-    }
-}
-
-impl StrHashGlobal {
-    pub(crate) fn new(s: SmartString<LazyCompact>, hash: u64) -> Self {
-        Self { str: s, hash }
-    }
-}
-
-impl PartialEq for StrHashGlobal {
-    fn eq(&self, other: &Self) -> bool {
-        // can be collisions in the hashtable even though the hashes are equal
-        // e.g. hashtable hash = hash % n_slots
-        (self.hash == other.hash) && (self.str == other.str)
-    }
-}
-
-impl Borrow<str> for StrHashGlobal {
-    fn borrow(&self) -> &str {
-        self.str.as_str()
-    }
-}
+type StrHashGlobal = SmartString<LazyCompact>;
