@@ -25,7 +25,7 @@ impl SortExec {
                 // therefore we rename more complex expressions so that
                 // polars core does not match these
                 if !matches!(e.as_expression(), Some(&Expr::Column(_))) {
-                    s.rename(&format!("_POLARS_SORT_BY_{}", i));
+                    s.rename(&format!("_POLARS_SORT_BY_{i}"));
                 }
                 Ok(s)
             })
