@@ -2,6 +2,7 @@ from __future__ import annotations
 
 import io
 import os
+import typing
 from typing import TYPE_CHECKING
 
 import numpy as np
@@ -182,6 +183,13 @@ def test_glob_parquet(io_test_dir: str) -> None:
     assert pl.scan_parquet(path).collect().shape == (3, 16)
 
 
+def test_streaming_parquet_glob_5900(io_test_dir: str) -> None:
+    path = os.path.join(io_test_dir, "small*.parquet")
+    assert pl.scan_parquet(path).select(pl.all().first()).collect(
+        streaming=True
+    ).shape == (1, 16)
+
+
 def test_chunked_round_trip() -> None:
     df1 = pl.DataFrame(
         {
@@ -264,3 +272,63 @@ def test_nested_sliced() -> None:
         df.write_parquet(f)
         f.seek(0)
         assert pl.read_parquet(f).frame_equal(df)
+
+
+def test_parquet_5795() -> None:
+    df_pd = pd.DataFrame(
+        {
+            "a": [
+                "V",
+                "V",
+                "V",
+                "V",
+                "V",
+                "V",
+                "V",
+                "V",
+                "V",
+                "V",
+                "V",
+                "V",
+                "V",
+                "V",
+                None,
+                None,
+                None,
+                None,
+                None,
+                None,
+            ]
+        }
+    )
+    f = io.BytesIO()
+    df_pd.to_parquet(f)
+    f.seek(0)
+    assert pl.read_parquet(f).frame_equal(pl.from_pandas(df_pd))
+
+
+@typing.no_type_check
+def test_parquet_nesting_structs_list() -> None:
+    f = io.BytesIO()
+    df = pl.from_records(
+        [
+            {
+                "id": 1,
+                "list_of_structs_col": [
+                    {"a": 10, "b": [10, 11, 12]},
+                    {"a": 11, "b": [13, 14, 15]},
+                ],
+            },
+            {
+                "id": 2,
+                "list_of_structs_col": [
+                    {"a": 44, "b": [12]},
+                ],
+            },
+        ]
+    )
+
+    df.write_parquet(f)
+    f.seek(0)
+
+    assert pl.read_parquet(f).frame_equal(df)
