@@ -29,9 +29,7 @@ def test_ascii_tables() -> None:
             "| i64 | i64 | i64 |\n"
             "+=================+\n"
             "| 1   | 4   | 7   |\n"
-            "|-----+-----+-----|\n"
             "| 2   | 5   | 8   |\n"
-            "|-----+-----+-----|\n"
             "| 3   | 6   | 9   |\n"
             "+-----+-----+-----+"
         )
@@ -45,9 +43,7 @@ def test_ascii_tables() -> None:
         "│ i64 ┆ i64 ┆ i64 │\n"
         "╞═════╪═════╪═════╡\n"
         "│ 1   ┆ 4   ┆ 7   │\n"
-        "├╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌┤\n"
         "│ 2   ┆ 5   ┆ 8   │\n"
-        "├╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌┤\n"
         "│ 3   ┆ 6   ┆ 9   │\n"
         "└─────┴─────┴─────┘"
     )
@@ -63,9 +59,7 @@ def test_hide_header_elements() -> None:
         "│ a   ┆ b   ┆ c   │\n"
         "╞═════╪═════╪═════╡\n"
         "│ 1   ┆ 4   ┆ 7   │\n"
-        "├╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌┤\n"
         "│ 2   ┆ 5   ┆ 8   │\n"
-        "├╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌┤\n"
         "│ 3   ┆ 6   ┆ 9   │\n"
         "└─────┴─────┴─────┘"
     )
@@ -77,9 +71,7 @@ def test_hide_header_elements() -> None:
         "│ i64 ┆ i64 ┆ i64 │\n"
         "╞═════╪═════╪═════╡\n"
         "│ 1   ┆ 4   ┆ 7   │\n"
-        "├╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌┤\n"
         "│ 2   ┆ 5   ┆ 8   │\n"
-        "├╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌┤\n"
         "│ 3   ┆ 6   ┆ 9   │\n"
         "└─────┴─────┴─────┘"
     )
@@ -133,7 +125,6 @@ def test_set_tbl_rows() -> None:
         "│ i64 ┆ i64 ┆ i64 │\n"
         "╞═════╪═════╪═════╡\n"
         "│ 1   ┆ 5   ┆ 9   │\n"
-        "├╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌┤\n"
         "│ ... ┆ ... ┆ ... │\n"
         "└─────┴─────┴─────┘"
     )
@@ -150,9 +141,7 @@ def test_set_tbl_rows() -> None:
         "│ i64 ┆ i64 ┆ i64 │\n"
         "╞═════╪═════╪═════╡\n"
         "│ 1   ┆ 5   ┆ 9   │\n"
-        "├╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌┤\n"
         "│ ... ┆ ... ┆ ... │\n"
-        "├╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌┤\n"
         "│ 4   ┆ 8   ┆ 12  │\n"
         "└─────┴─────┴─────┘"
     )
@@ -175,11 +164,8 @@ def test_set_tbl_rows() -> None:
         "│ i64 ┆ i64 ┆ i64 │\n"
         "╞═════╪═════╪═════╡\n"
         "│ 1   ┆ 5   ┆ 9   │\n"
-        "├╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌┤\n"
         "│ ... ┆ ... ┆ ... │\n"
-        "├╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌┤\n"
         "│ 3   ┆ 7   ┆ 11  │\n"
-        "├╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌┤\n"
         "│ 4   ┆ 8   ┆ 12  │\n"
         "└─────┴─────┴─────┘"
     )
@@ -203,11 +189,8 @@ def test_set_tbl_rows() -> None:
         "│ i64 ┆ i64 ┆ i64 │\n"
         "╞═════╪═════╪═════╡\n"
         "│ 1   ┆ 5   ┆ 9   │\n"
-        "├╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌┤\n"
         "│ 2   ┆ 6   ┆ 10  │\n"
-        "├╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌┤\n"
         "│ 3   ┆ 7   ┆ 11  │\n"
-        "├╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌┤\n"
         "│ 4   ┆ 8   ┆ 12  │\n"
         "└─────┴─────┴─────┘"
     )
@@ -240,11 +223,8 @@ def test_set_tbl_rows() -> None:
         "│ i64 ┆ i64 ┆ i64 │\n"
         "╞═════╪═════╪═════╡\n"
         "│ 1   ┆ 6   ┆ 11  │\n"
-        "├╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌┤\n"
         "│ ... ┆ ... ┆ ... │\n"
-        "├╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌┤\n"
         "│ 4   ┆ 9   ┆ 14  │\n"
-        "├╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌┤\n"
         "│ 5   ┆ 10  ┆ 15  │\n"
         "└─────┴─────┴─────┘"
     )
@@ -270,13 +250,9 @@ def test_set_tbl_rows() -> None:
         "│ i64 ┆ i64 ┆ i64 │\n"
         "╞═════╪═════╪═════╡\n"
         "│ 1   ┆ 6   ┆ 11  │\n"
-        "├╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌┤\n"
         "│ 2   ┆ 7   ┆ 12  │\n"
-        "├╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌┤\n"
         "│ 3   ┆ 8   ┆ 13  │\n"
-        "├╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌┤\n"
         "│ 4   ┆ 9   ┆ 14  │\n"
-        "├╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌┤\n"
         "│ 5   ┆ 10  ┆ 15  │\n"
         "└─────┴─────┴─────┘"
     )
@@ -368,13 +344,14 @@ def test_shape_below_table_and_inlined_dtype() -> None:
     df = pl.DataFrame({"a": [1, 2], "b": [3, 4], "c": [5, 6]})
 
     pl.Config.set_tbl_column_data_type_inline(True).set_tbl_dataframe_shape_below(True)
-    pl.Config.set_tbl_formatting("UTF8_FULL_CONDENSED")
+    pl.Config.set_tbl_formatting("UTF8_FULL")
     assert (
         str(df) == ""
         "┌─────────┬─────────┬─────────┐\n"
         "│ a (i64) ┆ b (i64) ┆ c (i64) │\n"
         "╞═════════╪═════════╪═════════╡\n"
         "│ 1       ┆ 3       ┆ 5       │\n"
+        "├╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌┤\n"
         "│ 2       ┆ 4       ┆ 6       │\n"
         "└─────────┴─────────┴─────────┘\n"
         "shape: (2, 3)"
@@ -387,6 +364,7 @@ def test_shape_below_table_and_inlined_dtype() -> None:
         "│ a (i64) ┆ b (i64) ┆ c (i64) │\n"
         "╞═════════╪═════════╪═════════╡\n"
         "│ 1       ┆ 3       ┆ 5       │\n"
+        "├╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌┤\n"
         "│ 2       ┆ 4       ┆ 6       │\n"
         "└─────────┴─────────┴─────────┘"
     )
@@ -400,6 +378,7 @@ def test_shape_below_table_and_inlined_dtype() -> None:
         "│ i64 ┆ i64 ┆ i64 │\n"
         "╞═════╪═════╪═════╡\n"
         "│   1 ┆   3 ┆   5 │\n"
+        "├╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌┤\n"
         "│   2 ┆   4 ┆   6 │\n"
         "└─────┴─────┴─────┘"
     )
@@ -470,7 +449,7 @@ def test_config_scope() -> None:
         new_state_entries = set(
             {
                 "POLARS_FMT_MAX_COLS": "8",
-                "POLARS_FMT_TABLE_FORMATTING": "ASCII_FULL",
+                "POLARS_FMT_TABLE_FORMATTING": "ASCII_FULL_CONDENSED",
                 "POLARS_FMT_TABLE_HIDE_COLUMN_SEPARATOR": "1",
                 "POLARS_VERBOSE": "1",
             }.items()
